@@ -781,9 +781,9 @@ def load_population():
 
     """ 
     df = pd.DataFrame()
-    df["年份"] = [i for i in  range(1790,2010,10)]
+    df["年份"] = [int(i) for i in  range(1790,2010,10)]
     df["人口"] = [3.9,5.3,7.2,9.6,12.9,17.1,23.2,31.4,38.6,50.2,62.9,76,92,106.5,123.2,131.7,150.7,179.3,204,226.5,251.4,281.4]
-    return df.T
+    return df
 
 
 ###########################################################################################
