@@ -662,15 +662,17 @@ def ahp(judge_matrix):
     n =  judge_matrix.shape[0]
     eigenvalues, eigenvectors = np.linalg.eig(judge_matrix)
     value_max = eigenvalues.max()
+    value_max_index = eigenvalues.argmax()
     CI = (value_max-n)/(n-1)
     RI_list = [0,0,0,0.58,0.9,1.12,1.24,1.32,1.41,1.45,1.49] 
     if CI/RI_list[n]>0.1:
         return 'Judgement Matrix is NOT consistent'
     else:
         print('The Max Eigenvalue is ',value_max)
-        ahp_weights = eigenvectors/eigenvectors.sum()
+        ahp_weights = eigenvectors[:,value_max_index]
+        ahp_weights = ahp_weights/ahp_weights.sum()
         return ahp_weights
-        
+
 
 ###########################################################################################
 ###############################        3 MCDM Models        ###############################
